summaryrefslogtreecommitdiff
path: root/lisp/emerge.el
diff options
context:
space:
mode:
authorJim Blandy <jimb@redhat.com>1992-07-15 02:24:58 +0000
committerJim Blandy <jimb@redhat.com>1992-07-15 02:24:58 +0000
commitf98955eaaa3d2c459b373a7b4c5d1176a18687d9 (patch)
tree23dc25a018ca240872c713d715420f96d3315e7d /lisp/emerge.el
parentdc6d96816db5f4f7b484e5e394501e5724c2d02f (diff)
downloademacs-f98955eaaa3d2c459b373a7b4c5d1176a18687d9.tar.gz
*** empty log message ***
Diffstat (limited to 'lisp/emerge.el')
-rw-r--r--lisp/emerge.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/lisp/emerge.el b/lisp/emerge.el
index bcb15da3aee..cf9fcebe94c 100644
--- a/lisp/emerge.el
+++ b/lisp/emerge.el
@@ -400,7 +400,7 @@
; number of lines or characters by which the windows are scrolled.
; Otherwise, the amount of motion is computed based on the dimensions of
; the merge buffer window -- the height of the merge buffer window
; (minus next-screen-context-lines), or half the width of the merge
; buffer window. (The A and B version windows are assumed to be as high
; as the merge window, but half as wide.) If the argument is just `C-u
; -', then the scrolling is half the default amount.
@@ -2898,7 +2898,7 @@ SPC, it is ignored; if it is anything else, it is processed as a command."
(if (not (pos-visible-in-window-p))
(let ((echo-keystrokes 0))
(while (and (not (pos-visible-in-window-p))
- (> (1- (screen-height)) (window-height)))
+ (> (1- (frame-height)) (window-height)))
(enlarge-window 1))
(let ((c (read-char)))
(if (/= c 32)
@@ -400,7 +400,7 @@
; Otherwise, the amount of motion is computed based on the dimensions of
; the merge buffer window -- the height of the merge buffer window
-; (minus next-screen-context-lines), or half the width of the merge
+; (minus next-frame-context-lines), or half the width of the merge
; buffer window. (The A and B version windows are assumed to be as high
; as the merge window, but half as wide.) If the argument is just `C-u